@@ -660,7 +660,7 @@ int vm_run(META *m, VM *vm)
 			n = meta_atoord(R.p, R.l, 0, 0, &g, 0);
 			if (!g && R.i) {
 				META_VAL *val;
-				val = meta_getvalbyname(0, R.i, R.p, R.l);
+				val = meta_getvalbyname(m, R.i, R.p, R.l);
 				if (val) n = val->nr;
 			}
 			meta_freeavdata(&R); R.p = 0; R.l = n; R.i = 0;
