@@ -133,7 +133,7 @@ typedef enum { RETURN, APP_GETKEY, APP_RECV, IA_RECV,
 /* command line arguments */
 
 META_ORD rx_space, tx_space, decpay_space;
-enum { DECPAY_RAW = 1, DECPAY_PEAP = 2, DECPAY_DIAMETER = 4 } decpay_type;
+enum { DECPAY_RAW = 1, DECPAY_PEAPv2 = 2, DECPAY_DIAMETER = 4 } decpay_type;
 int wantclientcert;
 STR_T keymat_label = cstr("client EAP encryption");
 int debug;
@@ -224,7 +224,7 @@ void parseoptions(int argc, char **argv)
         switch(c) {
 	  case 't': switch(*optarg) {
 			case 'r': decpay_type |= DECPAY_RAW; break;
-			case 'p': decpay_type |= DECPAY_PEAP; break;
+			case 'p': decpay_type |= DECPAY_PEAPv2; break;
 			case 't': 
 			case 'd': decpay_type |= DECPAY_DIAMETER; break;
 			default:  fprintf(stderr, "eaptls: Invalid payload "
@@ -474,8 +474,12 @@ int tls_state_machine(BUF_T *repbuf, CONV_T *conv, int app_action)
 	l = buf_maxget(&conv->totls_app);
 	if (!l) break;
 	gr = gnutls_record_send(conv->session, conv->totls_app.r, l); 
-	if (debug) fprintf(stderr, "eaptls: gnutls_record_send %d returned %d: %s\n", (int)l, gr, gr <= 0 ? gnutls_strerror(gr) : (gr < l ? "short write" : "all data sent"));
-	if (gr > 0) { if (gr > l) gr = l; buf_get(&conv->totls_app, gr); }
+	if (debug) fprintf(stderr, "eaptls: gnutls_record_send %d returned %d: %s\n", (int)l, gr, gr <= 0 ? gnutls_strerror(gr) : (gr < l ? "(short write)" : "(all data sent)"));
+	if (gr > 0) { 
+	    if (gr > l) gr = l; 
+	    buf_get(&conv->totls_app, gr); 
+	    break;
+	}
 	if (!gr || gr == GNUTLS_E_INTERRUPTED || gr == GNUTLS_E_AGAIN) break;
 	action = PRERROR;
 	break;
@@ -654,7 +658,9 @@ int main(int argc, char **argv)
          */
 
         /* Read header */
-        if (read(0, rxbuf, 8) != 8) { perror("eaptls: read"); break; }
+	l = read(0, rxbuf, 8);
+	if (l < 0) { perror("eaptls: read"); break; }
+	if (l < 8) { errputcs("eaptls: EOF or short read - exiting\n"); break; }
         if (net32(*rxbuf) != 0xbeefdead) {
             fprintf(stderr, "eaptls: Invalid magic 0x%08x!\n", net32(*rxbuf)); 
             break;
@@ -666,16 +672,18 @@ int main(int argc, char **argv)
         }
 
         /* Read rest of message */
-        if (read(0, rxbuf + 2, len - 8) != len - 8) {
-            perror("eaptls: read"); 
-            break;
-        }
+	l = read(0, rxbuf + 2, len - 8);
+	if (l < 0) { perror("eaptls: read"); 
+		     break; }
+	if (l < len - 8) { errputcs("eaptls: EOF or short read - exiting\n"); 
+			   break; }
 
 	/* Initialize defaults */
 
 	t = time(0);
 	conv = 0;
-	convnr = rx_flags = tx_flags = rx_action = ~0;
+	rx_flags = 0;
+	convnr = rx_action = ~0;
 	tls_data.l = 0;
 	rx_payload.l = 0;
 	mtu = 1230;
