@@ -66,11 +66,20 @@ static void job_process_recvlist(META_AV **heads, META_AV **tails, META_AV *acl,
 	/* Check if we're allowed to keep it and copy flags in the process.
 	 * It's a 'no' as soon as we encounter even one vote against it; it's a
 	 * yes only if there's a vote for and there are no votes against. An
-	 * ACL item with 'i' set to 0 counts as a wildcard. */
+	 * ACL item with nr set to 'x' (Any) counts as a wildcard for the whole
+	 * space. */
 
 	keep = 0;
 	for(auxav = acl; auxav; auxav = auxav->next) {
-	    if (auxav->i->nr != C_DI_ANY && auxav->i != av->i) continue;
+
+	    /* If the ACL item does not refer to the attribute we're checking,
+	     * and the ACL wildcard item's space does not match it either,
+	     * proceed to the next ACL item */
+
+	    if (auxav->i != av->i &&
+		(auxav->i->nr != C_DI_ANY || auxav->i->spc != av->i->spc))
+		    continue;
+
 	    if (auxav->ref.inst == AVR_INST_NO) { keep = 0; break; }
 	    keep++;
 
@@ -184,12 +193,16 @@ static void job_get_sendlist(META_AV **heads, META_AV **tails, META_AV *acl,
 
 	if ((aclav->ref.have & AVR_HAVE_INST) == 0) {
 
-	    /* Take all instances from referenced list */
+	    /* Take all instances of ACL attribute from referenced list. If
+	     * the ACL attribute has number 'x' (any), then take all instances
+	     * of all attributes in the same space. */
 
 	    for(av = heads[aclav->ref.list]; av; av = av->next) {
-		if ((aclav->i->nr != C_DI_ANY && av->i != aclav->i) ||
-		    av->flags & AV_DEL) continue;
-		meta_addnewav(sendhead, sendtail, 0, 0, av->i, av->p, av->l);
+		if (av->flags & AV_DEL) continue;
+		if (av->i == aclav->i ||
+		    (aclav->i->nr == C_DI_ANY && av->i->spc == aclav->i->spc)) {
+		    meta_addnewav(sendhead,sendtail, 0,0, av->i, av->p, av->l);
+		}
 	    }
 	    continue;
 	}
